@@ -894,7 +894,13 @@ class QuantumAnalysis(object):
         Qs.plot(ax=ax, lw=0, marker=markerf1, ms=4,
                 legend=True, zorder=20, color=cmap)
         Qs.plot(ax=ax, lw=1, alpha=0.2, color='grey', legend=False)
-        if not (len(Qs) == 0): 
+        
+        df_Qs = np.isinf(Qs)
+        # pylint: disable=E1101 
+        # Instance of 'ndarray' has no 'values' member (no-member)
+        Qs_val = df_Qs.values
+        Qs_inf = Qs_val.sum()
+        if not (len(Qs) == 0 or Qs_inf > 0): 
           ax.set_yscale('log')
 
         ############################################################################
